@@ -51,17 +51,18 @@ App::Cmd - write command line apps with less suffering
 
 =head1 VERSION
 
-version 0.303
+version 0.305
 
 =cut
 
-our $VERSION = '0.303';
+our $VERSION = '0.305';
 
 =head1 SYNOPSIS
 
 in F<yourcmd>:
 
-  use YourApp -run;
+  use YourApp;
+  YourApp->run;
 
 in F<YourApp.pm>:
 
@@ -579,7 +580,7 @@ sub global_opt_spec {
 
 =head2 usage_error
 
-  $self->usage_error("Your mother!");
+  $self->usage_error("Something's wrong!");
 
 Used to die with nice usage output, during C<validate_args>.
 
